==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterDecisionFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterDecisionFluent<A extends ClusterDecisionFluent<A>> extends BaseFluent<A>{
  public ClusterDecisionFluent() {
  }
  public ClusterDecisionFluent(ClusterDecision instance) {
    instance = (instance != null ? instance : new ClusterDecision());

    if (instance != null) {
      this.withClusterName(instance.getClusterName());
      this.withReason(instance.getReason());
      this.withClusterName(instance.getClusterName());
      this.withReason(instance.getReason());
    }
  }
  private String clusterName;
  private String reason;
  public String getClusterName() {
    return this.clusterName;
  }
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  public boolean hasClusterName() {
    return this.clusterName != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public boolean hasReason() {
    return this.reason != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDecisionFluent that = (ClusterDecisionFluent) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  reason,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterDecisionFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ClusterDecisionFluent<A extends ClusterDecisionFluent<A>> extends BaseFluent<A>{
  public ClusterDecisionFluent() {
  }
  
  public ClusterDecisionFluent(ClusterDecision instance) {
    this.copyInstance(instance);
  }
  private String clusterName;
  private String reason;
  
  protected void copyInstance(ClusterDecision instance) {
    instance = (instance != null ? instance : new ClusterDecision());
  
    if (instance != null) {
        this.withClusterName(instance.getClusterName());
        this.withReason(instance.getReason());
        this.withClusterName(instance.getClusterName());
        this.withReason(instance.getReason());
      }
  }
  
  public String getClusterName() {
    return this.clusterName;
  }
  
  public A withClusterName(String clusterName) {
    this.clusterName=clusterName; return (A) this;
  }
  
  public boolean hasClusterName() {
    return this.clusterName != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDecisionFluent that = (ClusterDecisionFluent) o;
    if (!java.util.Objects.equals(clusterName, that.clusterName)) return false;
  
    if (!java.util.Objects.equals(reason, that.reason)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clusterName,  reason,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterName != null) { sb.append("clusterName:"); sb.append(clusterName + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason); }
    sb.append("}");
    return sb.toString();
  }
  

}
